@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Game::Asset;
-$Game::Asset::VERSION = '0.1';
+$Game::Asset::VERSION = '0.2';
 # ABSTRACT: Load assets (images, music, etc.) for games
 use strict;
 use warnings;
@@ -34,6 +34,7 @@ use Game::Asset::Null;
 use Game::Asset::PerlModule;
 use Game::Asset::PlainText;
 use Game::Asset::YAML;
+use Game::Asset::MultiExample;
 
 use Archive::Zip qw( :ERROR_CODES );
 use YAML ();
@@ -224,6 +225,14 @@ The following mappings are always available without being in the index file:
 
 =back
 
+=head2 Multi-mappings
+
+There are times when the given content should be processed by more than one 
+mapping. For instance, a game may want to process a L<Graphics::GVG> vector 
+in both OpenGL and Chipmunk (physics library).
+
+This is what multi-mappings are for. See L<Game::Asset::Multi> for details.
+
 =head1 ATTRIBUTES
 
 =head2 file
